Historias das Ilhas : (Reminiscencias dos Açores e da Madeira) by Azevedo | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# Historias das Ilhas : (Reminiscencias dos Açores e da Madeira) by Azevedo

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75220.html.images | 366 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75220.epub3.images | 3.4 MB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/75220.epub.images | 3.4 MB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75220.epub.noimages | 260 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75220.kf8.images | 3.4 MB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75220.kindle.images | 3.3 MB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75220.txt.utf-8 | 311 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75220/pg75220-h.zip | 3.4 MB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Azevedo, Maximiliano de, 1850-1911
Illustrator | Herminio, Celso
Title | Historias das Ilhas : (Reminiscencias dos Açores e da Madeira)
Original Publication | LISBOA: Parceria Antonio Maria Pereira, 1899.
Credits | Pedro Saborano, Laura Natal and the Online Distributed Proofreading Team at https://www.pgdp.net (This book was produced from scanned images of public domain material from the Google Books project.)
Language | Portuguese
Category | Text
EBook-No. | 75220
Release Date | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 56 downloads in the last 30 days.
Project Gutenberg eBooks are always free!